==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/entity/GhostEntity.java <==
package cc.thonly.reverie_dreams.entity;

import cc.thonly.reverie_dreams.effect.ModStatusEffects;
import cc.thonly.reverie_dreams.entity.ai.goal.GhostStatusEffectTargetGoal;
import cc.thonly.reverie_dreams.entity.ai.goal.NPCFollowOwnerGoal;
import cc.thonly.reverie_dreams.entity.npc.NPCEntityImpl;
import cc.thonly.reverie_dreams.entity.skin.MobSkins;
import net.minecraft.class_11368;
import net.minecraft.class_11372;
import net.minecraft.class_1293;
import net.minecraft.class_1294;
import net.minecraft.class_1299;
import net.minecraft.class_1308;
import net.minecraft.class_1321;
import net.minecraft.class_1341;
import net.minecraft.class_1347;
import net.minecraft.class_1361;
import net.minecraft.class_1376;
import net.minecraft.class_1386;
import net.minecraft.class_1394;
import net.minecraft.class_1657;
import net.minecraft.class_1937;
import net.minecraft.class_2398;
import net.minecraft.class_3218;
import net.minecraft.entity.ai.goal.*;

public class GhostEntity extends NPCEntityImpl {
    protected int particleTick = 0;
    protected int survivalTime = 0;

    public GhostEntity(class_1299<? extends class_1321> entityType, class_1937 world) {
        super(entityType, world, MobSkins.GHOST.get());
    }

    public GhostEntity(class_1937 world) {
        super(ModEntities.GHOST_ENTITY_TYPE, world, MobSkins.GHOST.get());
    }

    @Override
    public void method_5773() {
        super.method_5773();
        class_1937 world = this.method_37908();
        this.particleTick++;
        if(!world.method_8608()) {
            if (!this.method_16914()
                    && !this.method_5765()
                    && this.method_5685().isEmpty()
                    && this.survivalTime > 600 * 20
            ) {
                this.method_31472();
            }
            if(this.survivalTime <= 600 * 20) {
                this.survivalTime++;
            }

            if (this.particleTick > 3) {
                if (world instanceof class_3218 serverWorld) {
                    serverWorld.method_65096(
                            class_2398.field_23956,
                            this.method_19538().field_1352,
                            this.method_19538().field_1351,
                            this.method_19538().field_1350,
                            1,
                            0,
                            1,
                            0,
                            0.1
                    );
                }
                this.particleTick = 0;
            }
            if (world.method_8530()) {
                class_1293 currentEffect = this.method_6112(class_1294.field_5905);
                if (currentEffect == null || currentEffect.method_5584() <= 20) {
                    this.method_6092(new class_1293(class_1294.field_5905, 60, 0, false, false));
                }
            }
        }
    }

    @Override
    public boolean method_5810() {
        return true;
    }

    @Override
    protected void method_5959() {
        super.method_5959();
        this.field_6201.method_6277(0, new class_1347(this));
        this.field_6201.method_6277(1, new class_1386(this));

        this.field_6201.method_6277(6, new NPCFollowOwnerGoal(this, 1.0, 2.0f, 10.0f));
        this.field_6201.method_6277(7, new class_1341(this, 1.0));
        this.field_6201.method_6277(8, new class_1394(this, 1.0));

        this.field_6201.method_6277(10, new class_1361(this, class_1657.class, 8.0f));
        this.field_6201.method_6277(10, new class_1361(this, NPCEntityImpl.class, 8.0f));
        this.field_6201.method_6277(10, new class_1376(this));

        this.field_6185.method_6277(2, new GhostStatusEffectTargetGoal<>(this, class_1657.class, true, ModStatusEffects.MENTAL_DISORDER));
        this.field_6185.method_6277(2, new GhostStatusEffectTargetGoal<>(this, class_1308.class, true, ModStatusEffects.MENTAL_DISORDER));
    }

    @Override
    protected void method_5652(class_11372 view) {
        super.method_5652(view);
        view.method_71465("SurvivalTime", this.survivalTime);
    }

    @Override
    public void method_5749(class_11368 view) {
        super.method_5749(view);
        this.survivalTime = view.method_71424("SurvivalTime", 0);
    }

    @Override
    public KeepInventoryTypes getKeepInventoryType() {
        return KeepInventoryTypes.NOT_DROP_ANY;
    }

    @Override
    public Boolean canPickItem() {
        return false;
    }
}

==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/entity/GhostEntity.java <==
package cc.thonly.reverie_dreams.entity;

import cc.thonly.reverie_dreams.registry.content.effect.RDStatusEffects;
import cc.thonly.reverie_dreams.entity.ai.goal.GhostStatusEffectTargetGoal;
import cc.thonly.reverie_dreams.entity.ai.goal.NPCFollowOwnerGoal;
import cc.thonly.reverie_dreams.entity.npc.BaseNPCLikeEntity;
import cc.thonly.reverie_dreams.registry.content.skin.MobSkinTypes;
import net.minecraft.class_11368;
import net.minecraft.class_11372;
import net.minecraft.class_1293;
import net.minecraft.class_1294;
import net.minecraft.class_1299;
import net.minecraft.class_1308;
import net.minecraft.class_1321;
import net.minecraft.class_1341;
import net.minecraft.class_1347;
import net.minecraft.class_1361;
import net.minecraft.class_1376;
import net.minecraft.class_1386;
import net.minecraft.class_1394;
import net.minecraft.class_1657;
import net.minecraft.class_1937;
import net.minecraft.class_2398;
import net.minecraft.class_3218;
import cc.thonly.reverie_dreams.registry.content.entity.RDEntityTypes;

public class GhostEntity extends BaseNPCLikeEntity {
    protected int particleTick = 0;
    protected int survivalTime = 0;

    public GhostEntity(class_1299<? extends class_1321> entityType, class_1937 world) {
        super(entityType, world, MobSkinTypes.GHOST);
    }

    public GhostEntity(class_1937 world) {
        super(RDEntityTypes.GHOST_ENTITY_TYPE, world, MobSkinTypes.GHOST);
    }

    @Override
    public void method_5773() {
        super.method_5773();
        class_1937 world = this.method_37908();
        this.particleTick++;
        if(!world.method_8608()) {
            if (!this.method_16914()
                    && !this.method_5765()
                    && this.method_5685().isEmpty()
                    && this.survivalTime > 600 * 20
            ) {
                this.method_31472();
            }
            if(this.survivalTime <= 600 * 20) {
                this.survivalTime++;
            }

            if (this.particleTick > 3) {
                if (world instanceof class_3218 serverWorld) {
                    serverWorld.method_65096(
                            class_2398.field_23956,
                            this.method_19538().field_1352,
                            this.method_19538().field_1351,
                            this.method_19538().field_1350,
                            1,
                            0,
                            1,
                            0,
                            0.1
                    );
                }
                this.particleTick = 0;
            }
            if (world.method_8530()) {
                class_1293 currentEffect = this.method_6112(class_1294.field_5905);
                if (currentEffect == null || currentEffect.method_5584() <= 20) {
                    this.method_6092(new class_1293(class_1294.field_5905, 60, 0, false, false));
                }
            }
        }
    }

    @Override
    public boolean method_5810() {
        return true;
    }

    @Override
    protected void method_5959() {
        super.method_5959();
        this.field_6201.method_6277(0, new class_1347(this));
        this.field_6201.method_6277(1, new class_1386(this));

        this.field_6201.method_6277(6, new NPCFollowOwnerGoal(this, 1.0, 2.0f, 10.0f));
        this.field_6201.method_6277(7, new class_1341(this, 1.0));
        this.field_6201.method_6277(8, new class_1394(this, 1.0));

        this.field_6201.method_6277(10, new class_1361(this, class_1657.class, 8.0f));
        this.field_6201.method_6277(10, new class_1361(this, BaseNPCLikeEntity.class, 8.0f));
        this.field_6201.method_6277(10, new class_1376(this));

        this.field_6185.method_6277(2, new GhostStatusEffectTargetGoal<>(this, class_1657.class, true, RDStatusEffects.MENTAL_DISORDER));
        this.field_6185.method_6277(2, new GhostStatusEffectTargetGoal<>(this, class_1308.class, true, RDStatusEffects.MENTAL_DISORDER));
    }

    @Override
    protected void method_5652(class_11372 view) {
        super.method_5652(view);
        view.method_71465("SurvivalTime", this.survivalTime);
    }

    @Override
    public void method_5749(class_11368 view) {
        super.method_5749(view);
        this.survivalTime = view.method_71424("SurvivalTime", 0);
    }

    @Override
    public KeepInventoryTypes getKeepInventoryType() {
        return KeepInventoryTypes.NOT_DROP_ANY;
    }

    @Override
    public Boolean canPickItem() {
        return false;
    }
}
